package server

import (
	"github.com/go-kratos/kratos/v2/log"
	"github.com/go-kratos/kratos/v2/middleware/recovery"
	"github.com/go-kratos/kratos/v2/middleware/tracing"
	"github.com/go-kratos/kratos/v2/transport/grpc"
	"hilo/api/service/demo"
	"hilo/app/service/demo/internal/conf"
	"hilo/app/service/demo/internal/handler"
	"time"
)

// NewGRPCServer new a gRPC server.
func NewGRPCServer(c *conf.Server, svc *handler.DemoHandler) *grpc.Server {
	var opts = []grpc.ServerOption{
		grpc.Middleware(
			recovery.Recovery(),
			tracing.Server(),
			ValidateParams(),
		),
	}
	if c.Grpc.Addr != "" {
		opts = append(opts, grpc.Address(c.Grpc.Addr))
	}
	if c.Grpc.Timeout != 0 {
		opts = append(opts, grpc.Timeout(time.Duration(c.Grpc.Timeout)*time.Second))
	}

	srv := grpc.NewServer(opts...)
	demo.RegisterDemoServer(srv, svc)

	logHelper = log.NewHelper(log.GetLogger())
	return srv
}
